updateAll method
Updates all values. Listeners are notified after all values have been updated.
Iterates over all entries in the map and updates them with the result of invoking update.
Implementation
@override
void updateAll(T Function(K key, T value) update) {
assert(_debugAssertNotDisposed());
_map!.updateAll(update);
notifyListeners();
}